import { type MaybeRefOrGetter } from 'vue';
import type { Spec, SpecConfiguration } from '../types';
export declare const emptySpecGenerator: () => Spec;
/**
 * Keep the raw spec content in a ref and update it when the configuration changes.
 */
export declare function useReactiveSpec({ specConfig, proxy, }: {
    specConfig?: MaybeRefOrGetter<SpecConfiguration>;
    proxy?: MaybeRefOrGetter<string>;
}): {
    rawSpec: import("vue").Ref<string>;
    parsedSpec: {
        tags?: {
            name: string;
            description: string;
            operations: {
                httpVerb: string;
                path: string;
                operationId?: string | undefined;
                name?: string | undefined;
                description?: string | undefined;
                information?: {
                    description?: string | undefined;
                    operationId?: string | number | undefined;
                    parameters?: {
                        name: string;
                        in?: string | undefined;
                        description?: string | undefined;
                        required?: boolean | undefined;
                        deprecated?: boolean | undefined;
                        allowEmptyValue?: boolean | undefined;
                        style?: "form" | "simple" | undefined;
                        explode?: boolean | undefined;
                        allowReserved?: boolean | undefined;
                        schema?: {
                            type: string;
                            name?: string | undefined;
                            example?: any;
                            default?: any;
                            format?: string | undefined;
                            description?: string | undefined;
                            properties?: Record<string, import("@readyapi/oas-utils").Schema> | undefined;
                        } | undefined;
                        example?: any;
                        examples?: (Map<string, any> & Omit<Map<string, any>, keyof Map<any, any>>) | undefined;
                    }[] | undefined;
                    responses?: Record<string, import("@readyapi/oas-utils").ScalarResponse> | undefined;
                    security?: any[] | undefined;
                    requestBody?: {
                        description?: string | undefined;
                        required?: boolean | undefined;
                        content?: import("@readyapi/oas-utils").RequestBodyMimeTypes | undefined;
                    } | undefined;
                    summary?: string | undefined;
                    tags?: string[] | undefined;
                    deprecated?: boolean | undefined;
                    'x-custom-examples'?: {
                        lang: string;
                        label: string;
                        source: string;
                    }[] | undefined;
                    'x-codeSamples'?: {
                        lang: string;
                        label: string;
                        source: string;
                    }[] | undefined;
                    'x-code-samples'?: {
                        lang: string;
                        label: string;
                        source: string;
                    }[] | undefined;
                } | undefined;
                pathParameters?: {
                    name: string;
                    in?: string | undefined;
                    description?: string | undefined;
                    required?: boolean | undefined;
                    deprecated?: boolean | undefined;
                    allowEmptyValue?: boolean | undefined;
                    style?: "form" | "simple" | undefined;
                    explode?: boolean | undefined;
                    allowReserved?: boolean | undefined;
                    schema?: {
                        type: string;
                        name?: string | undefined;
                        example?: any;
                        default?: any;
                        format?: string | undefined;
                        description?: string | undefined;
                        properties?: Record<string, import("@readyapi/oas-utils").Schema> | undefined;
                    } | undefined;
                    example?: any;
                    examples?: (Map<string, any> & Omit<Map<string, any>, keyof Map<any, any>>) | undefined;
                }[] | undefined;
            }[];
        }[] | undefined;
        info: {
            title?: string | undefined;
            description?: string | undefined;
            termsOfService?: string | undefined;
            contact?: {
                name?: string | undefined;
                url?: string | undefined;
                email?: string | undefined;
            } | undefined;
            license?: {
                name: string;
                url?: string | undefined;
            } | undefined;
            version?: string | undefined;
        } | {
            title?: string | undefined;
            description?: string | undefined;
            termsOfService?: string | undefined;
            contact?: {
                name?: string | undefined;
                url?: string | undefined;
                email?: string | undefined;
            } | undefined;
            license?: {
                name: string;
                url?: string | undefined;
            } | undefined;
            version?: string | undefined;
        } | {
            description?: string | undefined;
            title?: string | undefined;
            termsOfService?: string | undefined;
            contact?: {
                name?: string | undefined;
                url?: string | undefined;
                email?: string | undefined;
            } | undefined;
            version?: string | undefined;
            summary?: string | undefined;
            license?: {
                url?: string | undefined;
                name: string;
                identifier?: string | undefined;
            } | undefined;
        };
        host?: string | undefined;
        basePath?: string | undefined;
        schemes?: string[] | undefined;
        externalDocs?: {
            description: string;
            url: string;
        } | undefined;
        servers?: {
            url: string;
            description?: string | undefined;
            variables?: import("../types").ServerVariables | undefined;
        }[] | undefined;
        components?: {
            schemas?: {
                [key: string]: import("@readyapi/openapi-parser").OpenAPIV3.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.SchemaObject;
            } | undefined;
            responses?: {
                [key: string]: import("@readyapi/openapi-parser").OpenAPIV3.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.ResponseObject;
            } | undefined;
            parameters?: {
                [key: string]: import("@readyapi/openapi-parser").OpenAPIV3.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.ParameterObject;
            } | undefined;
            examples?: {
                [key: string]: import("@readyapi/openapi-parser").OpenAPIV3.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.ExampleObject;
            } | undefined;
            requestBodies?: {
                [key: string]: import("@readyapi/openapi-parser").OpenAPIV3.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.RequestBodyObject;
            } | undefined;
            headers?: {
                [key: string]: import("@readyapi/openapi-parser").OpenAPIV3.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.HeaderObject;
            } | undefined;
            securitySchemes?: {
                [key: string]: import("@readyapi/openapi-parser").OpenAPIV3.SecuritySchemeObject | import("@readyapi/openapi-parser").OpenAPIV3.ReferenceObject;
            } | undefined;
            links?: {
                [key: string]: import("@readyapi/openapi-parser").OpenAPIV3.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.LinkObject;
            } | undefined;
            callbacks?: {
                [key: string]: import("@readyapi/openapi-parser").OpenAPIV3.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.CallbackObject;
            } | undefined;
        } | {
            schemas?: Record<string, import("@readyapi/openapi-parser").OpenAPIV3_1.SchemaObject> | undefined;
            responses?: Record<string, import("@readyapi/openapi-parser").OpenAPIV3_1.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3_1.ResponseObject> | undefined;
            parameters?: Record<string, import("@readyapi/openapi-parser").OpenAPIV3_1.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.ParameterObject> | undefined;
            examples?: Record<string, import("@readyapi/openapi-parser").OpenAPIV3_1.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.ExampleObject> | undefined;
            requestBodies?: Record<string, import("@readyapi/openapi-parser").OpenAPIV3_1.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3_1.RequestBodyObject> | undefined;
            headers?: Record<string, import("@readyapi/openapi-parser").OpenAPIV3_1.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3.HeaderObject> | undefined;
            securitySchemes?: Record<string, import("@readyapi/openapi-parser").OpenAPIV3.SecuritySchemeObject | import("@readyapi/openapi-parser").OpenAPIV3_1.ReferenceObject> | undefined;
            links?: Record<string, import("@readyapi/openapi-parser").OpenAPIV3_1.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3_1.LinkObject> | undefined;
            callbacks?: Record<string, import("@readyapi/openapi-parser").OpenAPIV3_1.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3_1.CallbackObject> | undefined;
            pathItems?: Record<string, import("@readyapi/openapi-parser").OpenAPIV3_1.ReferenceObject | import("@readyapi/openapi-parser").OpenAPIV3_1.PathItemObject<{}>> | undefined;
        } | undefined;
        webhooks?: import("../types").Webhooks | undefined;
        definitions?: import("@readyapi/openapi-parser").OpenAPIV2.DefinitionsObject | undefined;
        swagger?: string | undefined;
        openapi?: string | undefined;
        'x-tagGroups'?: {
            name: string;
            tags: string[];
        }[] | undefined;
        security?: import("@readyapi/openapi-parser").OpenAPIV3.SecurityRequirementObject[] | undefined;
    };
    specErrors: import("vue").Ref<string | null>;
};
//# sourceMappingURL=useReactiveSpec.d.ts.map